Bioontologies |release| Documentation
=====================================
Table of Contents
-----------------
.. toctree::
   :maxdepth: 2

   installation
   usage
   cli

Indices and Tables
------------------
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
